@@ -67,9 +67,9 @@
       (yellow-warmer   "#cfaf00")
       (yellow-cooler   "#bfaf7a")
       (yellow-faint    "#af9a6a")
-      (blue            "#3f95f6")
+      (blue            "#3f90f0")
       (blue-warmer     "#6a9fff")
-      (blue-cooler     "#1f90ff")
+      (blue-cooler     "#009fff")
       (blue-faint      "#7a94df")
       (magenta         "#b379bf")
       (magenta-warmer  "#af80ea")
@@ -154,6 +154,9 @@
       (type magenta-cooler)
       (variable cyan-cooler)
 
+      (rx-escape yellow-faint) ; compare with `string'
+      (rx-construct yellow-warmer)
+
       (accent-0 blue-cooler)
       (accent-1 yellow-warmer)
       (accent-2 cyan-warmer)
@@ -164,13 +167,14 @@
       (mail-2 blue-cooler)
       (mail-3 yellow-cooler)
       (mail-4 cyan)
+      (mail-5 cyan-cooler)
 
       (rainbow-0 yellow-warmer)
       (rainbow-1 blue)
       (rainbow-2 yellow-cooler)
       (rainbow-3 blue-warmer)
       (rainbow-4 yellow)
-      (rainbow-5 blue-cooler)
+      (rainbow-5 cyan-warmer)
       (rainbow-6 yellow-faint)
       (rainbow-7 blue-faint)
       (rainbow-8 magenta-faint))
